@@ -260,29 +260,34 @@ namespace Breeze
     {
 
         QColor outline;
+        const QColor hoverColor( this->hoverColor( palette ) );
+        const QColor focusColor( this->focusColor( palette ) );
+        const QColor sunkenColor = alphaColor( palette.color( QPalette::WindowText ), 0.2 );
 
         // hover takes precedence over focus
         if( mode == AnimationHover )
         {
 
-            const QColor hover( hoverColor( palette ) );
-            const QColor focus( focusColor( palette ) );
-            if( hasFocus || sunken ) outline = KColorUtils::mix( focus, hover, opacity );
-            else outline = alphaColor( hover, opacity );
+            if( hasFocus ) outline = KColorUtils::mix( focusColor, hoverColor, opacity );
+            else if( sunken ) outline = sunkenColor;
+            else outline = alphaColor( hoverColor, opacity );
 
         } else if( mouseOver ) {
 
-            outline = hoverColor( palette );
+            outline = hoverColor;
 
         } else if( mode == AnimationFocus ) {
 
-            const QColor focus( focusColor( palette ) );
-            if( sunken ) outline = focus;
-            else outline = alphaColor( focus, opacity );
+            if( sunken ) outline = KColorUtils::mix( sunkenColor, focusColor, opacity );
+            else outline = alphaColor( focusColor, opacity );
 
-        } else if( hasFocus || sunken ) {
+        } else if( hasFocus ) {
 
-            outline = focusColor( palette );
+            outline = focusColor;
+
+        } else if( sunken ) {
+
+            outline = sunkenColor;
 
         }
 
@@ -362,7 +367,7 @@ namespace Breeze
     QColor Helper::checkBoxIndicatorColor( const QPalette& palette, bool mouseOver, bool active, qreal opacity, AnimationMode mode ) const
     {
 
-        QColor color( KColorUtils::mix( palette.color( QPalette::Window ), palette.color( QPalette::WindowText ), 0.5 ) );
+        QColor color( KColorUtils::mix( palette.color( QPalette::Window ), palette.color( QPalette::WindowText ), 0.6 ) );
         if( mode == AnimationHover )
         {
 
@@ -422,10 +427,21 @@ namespace Breeze
         painter->restore();
     }
 
+    //______________________________________________________________________________
+    void Helper::renderFocusRect( QPainter* painter, const QRect& rect, const QColor& color ) const
+    {
+        if( !color.isValid() ) return;
+
+        painter->save();
+        painter->setBrush( color );
+        painter->setPen( Qt::NoPen );
+        painter->drawRect( rect );
+        painter->restore();
+    }
+
     //______________________________________________________________________________
     void Helper::renderFocusLine( QPainter* painter, const QRect& rect, const QColor& color ) const
     {
-
         if( !color.isValid() ) return;
 
         painter->save();
@@ -436,7 +452,6 @@ namespace Breeze
         painter->translate( 0, 2 );
         painter->drawLine( rect.bottomLeft(), rect.bottomRight() );
         painter->restore();
-
     }
 
     //______________________________________________________________________________
@@ -779,22 +794,22 @@ namespace Breeze
         if( !sunken )
         {
 
-            painter->setPen( QPen( shadow, 2 ) );
+            painter->setPen( QPen( shadow, 1 ) );
             painter->setBrush( Qt::NoBrush );
 
             const qreal shadowRadius( radius + 0.5 );
-            painter->drawRoundedRect( shadowRect( frameRect ), shadowRadius, shadowRadius );
+            painter->drawRoundedRect( shadowRect( frameRect ).adjusted( -0.5, -0.5, 0.5, 0.5 ), shadowRadius, shadowRadius );
 
         }
 
         // content
         {
 
-            painter->setPen( QPen( color, 2 ) );
+            painter->setPen( QPen( color, 1 ) );
             painter->setBrush( Qt::NoBrush );
 
-            const QRectF contentRect( frameRect.adjusted( 1, 1, -1, -1 ) );
-            painter->drawRoundedRect( contentRect, radius, radius );
+            const QRectF contentRect( frameRect.adjusted( 0.5, 0.5, -0.5, -0.5 ) );
+            painter->drawRoundedRect( contentRect, radius - 1.0, radius - 1.0 );
 
         }
 
@@ -805,7 +820,7 @@ namespace Breeze
             painter->setBrush( color );
             painter->setPen( Qt::NoPen );
 
-            const QRectF markerRect( frameRect.adjusted( 4, 4, -4, -4 ) );
+            const QRectF markerRect( frameRect.adjusted( 3, 3, -3, -3 ) );
             painter->drawRect( markerRect );
 
         } else if( state == CheckPartial ) {
@@ -814,7 +829,7 @@ namespace Breeze
             pen.setJoinStyle( Qt::MiterJoin );
             painter->setPen( pen );
 
-            const QRectF markerRect( frameRect.adjusted( 5, 5, -5, -5 ) );
+            const QRectF markerRect( frameRect.adjusted( 4, 4, -4, -4 ) );
             painter->drawRect( markerRect );
 
             painter->setPen( Qt::NoPen );
@@ -822,9 +837,9 @@ namespace Breeze
             painter->setRenderHint( QPainter::Antialiasing, false );
 
             QPainterPath path;
-            path.moveTo( 5, 5 );
-            path.lineTo( qreal( Metrics::CheckBox_Size ) -6, 5 );
-            path.lineTo( 5, qreal( Metrics::CheckBox_Size ) - 6 );
+            path.moveTo( 4, 4 );
+            path.lineTo( qreal( Metrics::CheckBox_Size ) -5, 4 );
+            path.lineTo( 4, qreal( Metrics::CheckBox_Size ) - 5 );
             painter->drawPath( path.translated( rect.topLeft() ) );
 
         } else if( state == CheckAnimated ) {
@@ -863,19 +878,19 @@ namespace Breeze
         if( !sunken )
         {
 
-            painter->setPen( QPen( shadow, 2 ) );
+            painter->setPen( QPen( shadow, 1 ) );
             painter->setBrush( Qt::NoBrush );
-            painter->drawEllipse( shadowRect( frameRect ) );
+            painter->drawEllipse( shadowRect( frameRect ).adjusted( -0.5, -0.5, 0.5, 0.5 ) );
 
         }
 
         // content
         {
 
-            painter->setPen( QPen( color, 2 ) );
+            painter->setPen( QPen( color, 1 ) );
             painter->setBrush( Qt::NoBrush );
 
-            const QRectF contentRect( frameRect.adjusted( 1, 1, -1, -1 ) );
+            const QRectF contentRect( frameRect.adjusted( 0.5, 0.5, -0.5, -0.5 ) );
             painter->drawEllipse( contentRect );
 
         }
@@ -887,14 +902,14 @@ namespace Breeze
             painter->setBrush( color );
             painter->setPen( Qt::NoPen );
 
-            const QRectF markerRect( frameRect.adjusted( 4, 4, -4, -4 ) );
+            const QRectF markerRect( frameRect.adjusted( 3, 3, -3, -3 ) );
             painter->drawEllipse( markerRect );
 
         } else if( state == RadioAnimated ) {
 
             painter->setBrush( color );
             painter->setPen( Qt::NoPen );
-            QRectF markerRect( frameRect.adjusted( 4, 4, -4, -4 ) );
+            QRectF markerRect( frameRect.adjusted( 3, 3, -3, -3 ) );
 
             painter->translate( markerRect.center() );
             painter->rotate( 45 );
